/// <reference types="react" />
import { ContentfulDataSource } from '../../dataSource';
/**
 * The result is in one of 3 states:
 * 1. Loading, no result available
 * 2. Error, result may or may not be available
 * 3. Success, result is available
 *
 * Re-running the query does not set "loading: true", the loading flag is intended
 * for the initial load use case.
 */
export type UseQueryResult<TResult> = [
    TResult | undefined,
    {
        error?: Error;
        loading: boolean;
        refreshing: boolean;
    },
    () => Promise<void>
];
/**
 * Executes an arbitrary query against the dataSource.  The result is stored in the
 * first element of the returned tuple.
 *
 * The result will be undefined until the query successfully completes the first time.
 * The query will be rerun whenever the dataSource is updated or one of the "deps" changes.
 */
export declare function useQuery<TResult>(
/**
 * The query to execute.  The return value is stored in the first element of the returned tuple.
 */
query: (dataSource: ContentfulDataSource) => Promise<TResult> | TResult, 
/**
 * Control when the query will be re-run.  The query is always re-run when the dataSource is updated.
 */
deps?: React.DependencyList): UseQueryResult<TResult>;
