import { Entry } from './contentful/types';
import { ContentfulDataSource } from './dataSource';
export interface DataSourceWithResolve extends ContentfulDataSource {
    /** Given an entry, resolves it down to the specified depth */
    resolveEntry<T extends Record<string, unknown>>(entry: Entry<T>, depth: number): Promise<Entry<T>>;
}
/**
 * Wraps a data source to automatically resolve linked entries and assets,
 * replacing links recursively down the tree by fetching the linked entries
 * by ID.
 */
export declare function withResolve<TDataSource extends ContentfulDataSource>(dataSource: TDataSource): TDataSource;
/**
 * Enhances a DataSource to automatically resolve linked entries and assets,
 * replacing links recursively down the tree by fetching the linked entries
 * by ID.
 */
export declare function addResolve<TDataSource extends ContentfulDataSource>(dataSource: TDataSource): asserts dataSource is TDataSource & DataSourceWithResolve;
export declare function hasResolveEntry(dataSource: any): dataSource is DataSourceWithResolve;
